package util

import (
	"context"
	"fmt"
	"github.com/docker/docker/client"
)

func ImageExists(cli *client.Client, imageName string) bool {
	defer func() {
		if r := recover(); r != nil {
			fmt.Println("Recovered from panic:", r)
		}
	}()

	// 设置上下文
	ctx := context.Background()

	// 检查镜像是否存在
	_, _, err := cli.ImageInspectWithRaw(ctx, imageName)
	if err != nil {
		if client.IsErrNotFound(err) {
			// 镜像不存在
			return false
		}
		// 处理其他错误
		fmt.Println("Error inspecting image:", err)
		return false
	}

	// 镜像存在
	return true
}
